@@ -62,18 +62,13 @@ func main() {
 		panic(err)
 	}
 
-	removeUnreleasedDocs()
+	removeUnreleasedCommands("custom-code-logging")
 
 	if err := os.Setenv("HOME", home); err != nil {
 		panic(err)
 	}
 }
 
-func removeUnreleasedDocs() {
-	removeUnreleasedCommands("iam certificate-authority")
-	removeUnreleasedCommands("iam certificate-pool")
-}
-
 func removeUnreleasedCommands(command string) {
 	subcommands := strings.Split(command, " ")
 
