@@ -3,6 +3,7 @@ package internal
 import (
 	"fmt"
 	"os"
+	"runtime/debug"
 	"strings"
 
 	shell "github.com/brianstrauch/cobra-shell"
@@ -35,7 +36,6 @@ import (
 	"github.com/confluentinc/cli/v4/internal/logout"
 	"github.com/confluentinc/cli/v4/internal/network"
 	"github.com/confluentinc/cli/v4/internal/organization"
-	"github.com/confluentinc/cli/v4/internal/pipeline"
 	"github.com/confluentinc/cli/v4/internal/plugin"
 	"github.com/confluentinc/cli/v4/internal/prompt"
 	providerintegration "github.com/confluentinc/cli/v4/internal/provider-integration"
@@ -54,6 +54,7 @@ import (
 	"github.com/confluentinc/cli/v4/pkg/form"
 	"github.com/confluentinc/cli/v4/pkg/help"
 	"github.com/confluentinc/cli/v4/pkg/jwt"
+	"github.com/confluentinc/cli/v4/pkg/log"
 	"github.com/confluentinc/cli/v4/pkg/output"
 	ppanic "github.com/confluentinc/cli/v4/pkg/panic-recovery"
 	pplugin "github.com/confluentinc/cli/v4/pkg/plugin"
@@ -113,6 +114,7 @@ func NewConfluentCommand(cfg *config.Config) *cobra.Command {
 	cmd.AddCommand(ccl.New(cfg, prerunner))
 	cmd.AddCommand(environment.New(prerunner))
 	cmd.AddCommand(feedback.New(prerunner))
+	cmd.AddCommand(flink.New(cfg, prerunner))
 	cmd.AddCommand(iam.New(cfg, prerunner))
 	cmd.AddCommand(kafka.New(cfg, prerunner))
 	cmd.AddCommand(ksql.New(cfg, prerunner))
@@ -121,7 +123,6 @@ func NewConfluentCommand(cfg *config.Config) *cobra.Command {
 	cmd.AddCommand(logout.New(cfg, prerunner, authTokenHandler))
 	cmd.AddCommand(network.New(prerunner))
 	cmd.AddCommand(organization.New(prerunner))
-	cmd.AddCommand(pipeline.New(prerunner))
 	cmd.AddCommand(plugin.New(cfg, prerunner))
 	cmd.AddCommand(prompt.New(cfg))
 	cmd.AddCommand(providerintegration.New(prerunner))
@@ -137,9 +138,6 @@ func NewConfluentCommand(cfg *config.Config) *cobra.Command {
 	if cfg.IsTest || featureflags.Manager.BoolVariation("cli.ai.enable", cfg.Context(), config.CliLaunchDarklyClient, true, false) {
 		cmd.AddCommand(ai.New(prerunner))
 	}
-	if cfg.IsTest || featureflags.Manager.BoolVariation("cli.flink", cfg.Context(), config.CliLaunchDarklyClient, true, false) {
-		cmd.AddCommand(flink.New(cfg, prerunner))
-	}
 
 	changeDefaults(cmd, cfg)
 	deprecateCommandsAndFlags(cmd, cfg)
@@ -151,8 +149,8 @@ func NewConfluentCommand(cfg *config.Config) *cobra.Command {
 func Execute(cmd *cobra.Command, args []string, cfg *config.Config) error {
 	defer func() {
 		if r := recover(); r != nil {
-			if !cfg.Version.IsReleased() {
-				panic(r)
+			if !cfg.IsCloudLogin() || cfg.HasGovHostname() || !cfg.Version.IsReleased() {
+				log.CliLogger.Trace(string(debug.Stack()))
 			}
 			u := ppanic.CollectPanic(cmd, args, cfg)
 			if err := reportUsage(cmd, cfg, u); err != nil {
