@@ -1,6 +1,8 @@
 package flink
 
 import (
+	"fmt"
+
 	"github.com/spf13/cobra"
 
 	pcmd "github.com/confluentinc/cli/v4/pkg/cmd"
@@ -48,6 +50,9 @@ func (c *command) describe(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
+	if _, err = c.V2Client.GetOrgEnvironment(environment); err != nil {
+		return fmt.Errorf("environment '%s' not found", environment)
+	}
 
 	artifact, err := c.V2Client.DescribeFlinkArtifact(cloud, region, environment, args[0])
 	if err != nil {
