@@ -13,9 +13,14 @@ import (
 	"github.com/confluentinc/cli/v4/pkg/utils"
 )
 
+const envNotFoundErrorMsg = "Failed to get environment '%s'. List available environments with `confluent environment list`."
+
 type connectionOut struct {
 	CreationDate time.Time `human:"Creation Date" serialized:"creation_date"`
 	Name         string    `human:"Name" serialized:"name"`
+	Environment  string    `human:"Environment" serialized:"environment"`
+	Cloud        string    `human:"Cloud" serialized:"cloud"`
+	Region       string    `human:"Region" serialized:"region"`
 	Type         string    `human:"Type" serialized:"type"`
 	Endpoint     string    `human:"Endpoint" serialized:"endpoint"`
 	Data         string    `human:"Data" serialized:"data"`
