@@ -77,16 +77,6 @@ func (c *clusterCommand) create(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	availabilityString, err := cmd.Flags().GetString("availability")
-	if err != nil {
-		return err
-	}
-
-	availability, err := stringToAvailability(availabilityString)
-	if err != nil {
-		return err
-	}
-
 	clusterType, err := cmd.Flags().GetString("type")
 	if err != nil {
 		return err
@@ -97,6 +87,16 @@ func (c *clusterCommand) create(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	availabilityString, err := cmd.Flags().GetString("availability")
+	if err != nil {
+		return err
+	}
+
+	availability, err := stringToAvailability(availabilityString, sku)
+	if err != nil {
+		return err
+	}
+
 	environmentId, err := c.Context.EnvironmentId()
 	if err != nil {
 		return err
@@ -163,9 +163,15 @@ func (c *clusterCommand) create(cmd *cobra.Command, args []string) error {
 	return c.outputKafkaClusterDescription(cmd, &kafkaCluster, false)
 }
 
-func stringToAvailability(s string) (string, error) {
-	if modelAvailability, ok := availabilitiesToModel[s]; ok {
-		return modelAvailability, nil
+func stringToAvailability(s string, sku ccstructs.Sku) (string, error) {
+	if sku == ccstructs.Sku_FREIGHT {
+		if modelAvailability, ok := availabilitiesToFreightModel[s]; ok {
+			return modelAvailability, nil
+		}
+	} else {
+		if modelAvailability, ok := availabilitiesToModel[s]; ok {
+			return modelAvailability, nil
+		}
 	}
 	return "", errors.NewErrorWithSuggestions(
 		fmt.Sprintf("invalid value \"%s\" for `--availability` flag", s),
