@@ -88,6 +88,12 @@ func (c *command) gatewayList(cmd *cobra.Command, _ []string) error {
 			out.Region = gateway.Spec.Config.NetworkingV1AwsPrivateNetworkInterfaceGatewaySpec.GetRegion()
 			out.Zones = gateway.Spec.Config.NetworkingV1AwsPrivateNetworkInterfaceGatewaySpec.GetZones()
 		}
+		if gateway.Spec.Config != nil && gateway.Spec.Config.NetworkingV1GcpPeeringGatewaySpec != nil {
+			out.Region = gateway.Spec.Config.NetworkingV1GcpPeeringGatewaySpec.GetRegion()
+		}
+		if gatewayType == gcpEgressPrivateServiceConnect {
+			out.Region = gateway.Spec.Config.NetworkingV1GcpEgressPrivateServiceConnectGatewaySpec.GetRegion()
+		}
 
 		switch getGatewayCloud(gateway) {
 		case pcloud.Aws:
@@ -98,6 +104,9 @@ func (c *command) gatewayList(cmd *cobra.Command, _ []string) error {
 			}
 		case pcloud.Azure:
 			out.AzureSubscription = gateway.Status.CloudGateway.NetworkingV1AzureEgressPrivateLinkGatewayStatus.GetSubscription()
+		case pcloud.Gcp:
+			out.GcpIamPrincipal = gateway.Status.CloudGateway.NetworkingV1GcpPeeringGatewayStatus.GetIamPrincipal()
+			out.GcpProject = gateway.Status.CloudGateway.NetworkingV1GcpEgressPrivateServiceConnectGatewayStatus.GetProject()
 		}
 
 		list.Add(out)
