@@ -3,15 +3,13 @@ package schemaregistry
 import (
 	"github.com/spf13/cobra"
 
-	pcmd "github.com/confluentinc/cli/v4/pkg/cmd"
 	"github.com/confluentinc/cli/v4/pkg/config"
 )
 
 func (c *command) newSubjectCommand(cfg *config.Config) *cobra.Command {
 	cmd := &cobra.Command{
-		Use:         "subject",
-		Short:       "Manage Schema Registry subjects.",
-		Annotations: map[string]string{pcmd.RunRequirement: pcmd.RequireCloudLoginOrOnPremLogin},
+		Use:   "subject",
+		Short: "Manage Schema Registry subjects.",
 	}
 
 	cmd.AddCommand(c.newSubjectDescribeCommand(cfg))
