@@ -1,11 +1,7 @@
 package secret
 
 import (
-	"fmt"
-
 	"github.com/spf13/cobra"
-
-	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
 )
 
 const masterKeyNotSetWarning = "This command fails if a master key has not been set in the environment variable `CONFLUENT_SECURITY_MASTER_KEY`. Create a master key using `confluent secret master-key generate`."
@@ -48,17 +44,3 @@ func (c *command) getConfigFilePath(cmd *cobra.Command) (string, string, string,
 
 	return configFile, localSecretsFile, remoteSecretsFile, nil
 }
-
-func (c *command) getConfigs(configSource, inputType, prompt string, secure bool) (string, error) {
-	newConfigs, err := c.flagResolver.ValueFrom(configSource, prompt, secure)
-	if err != nil {
-		switch err {
-		case pcmd.ErrNoValueSpecified:
-			return "", fmt.Errorf("enter %s", inputType)
-		case pcmd.ErrNoPipe:
-			return "", fmt.Errorf("pipe %s over stdin", inputType)
-		}
-		return "", err
-	}
-	return newConfigs, nil
-}
