@@ -14,7 +14,6 @@ func TestIsCCloudURL_True(t *testing.T) {
 		"https://devel.cpdev.cloud/",
 		"devel.cpdev.cloud",
 		"stag.cpdev.cloud",
-		"premium-oryx.gcp.priv.cpdev.cloud",
 	} {
 		isCCloud := IsCCloudURL(url, false)
 		require.True(t, isCCloud, url+" should return true")
@@ -34,11 +33,10 @@ func TestIsCCloudURL_False(t *testing.T) {
 
 func TestGetServerUrl(t *testing.T) {
 	m := map[string]string{
-		"https://confluent.cloud":                  "https://api.confluent.cloud",
-		"https://devel.cpdev.cloud":                "https://api.devel.cpdev.cloud",
-		"https://stag.cpdev.cloud":                 "https://api.stag.cpdev.cloud",
-		"https://stag.cpdev.cloud/":                "https://api.stag.cpdev.cloud",
-		"https://healthy-fox.gcp.priv.cpdev.cloud": "https://healthy-fox.gcp.priv.cpdev.cloud/api",
+		"https://confluent.cloud":   "https://api.confluent.cloud",
+		"https://devel.cpdev.cloud": "https://api.devel.cpdev.cloud",
+		"https://stag.cpdev.cloud":  "https://api.stag.cpdev.cloud",
+		"https://stag.cpdev.cloud/": "https://api.stag.cpdev.cloud",
 	}
 
 	for baseUrl, serverUrl := range m {
